@@ -19,4 +19,9 @@
 #ifndef __GEGL_BUFFER_ITERATOR_PRIVATE_H__
 #define __GEGL_BUFFER_ITERATOR_PRIVATE_H__
 
+G_STATIC_ASSERT (GEGL_BUFFER_READWRITE == 0x3);
+
+#define GEGL_ITERATOR_INCOMPATIBLE (1 << 2)
+#define GEGL_ITERATOR_NO_NOTIFY    (1 << 3)
+
 #endif
