@@ -18,6 +18,7 @@
 
 #include "config.h"
 #include "gegl.h"
+#include <glib/gi18n-lib.h>
 #include <string.h>
 #include <limits.h>
 #include <stdlib.h>
@@ -144,7 +145,17 @@ gegl_create_chain_argv (char      **ops,
           else
             {
               if (!(g_str_equal (key, "}")))
-                fprintf (stderr, "unhandled path data %s:%s\n", key, value);
+              {
+                if (error)
+                  {
+                    char *error_str = g_strdup_printf (
+                       _("unhandled path data %s:%s\n"), key, value);
+                    *error = g_error_new_literal (
+                                g_quark_from_static_string ( "gegl"),
+                                0, error_str);
+                    g_free (error_str);
+                  }
+              }
             }
 
           g_free (key);
@@ -368,7 +379,7 @@ gegl_create_chain_argv (char      **ops,
                               {
                                 GString *str = g_string_new ("");
                                 g_string_append_printf (str,
-                                                        "op '%s' not found, partial matches: ",
+                                                        _("op '%s' not found, partial matches: "),
                                                         level_op[level]);
 
                                 *error = g_error_new_literal (g_quark_from_static_string (
@@ -397,13 +408,13 @@ gegl_create_chain_argv (char      **ops,
                             if (n_props <= 0)
                               {
                                 g_string_append_printf (str,
-                                                        "%s has no %s property.",
+                                                        _("%s has no %s property."),
                                                         level_op[level], key);
                               }
                             else
                               {
                                 g_string_append_printf (str,
-                                                        "%s has no %s property, properties: ",
+                                                        _("%s has no %s property, properties: "),
                                                         level_op[level], key);
 
                                 for (i = 0; i < n_props; i++)
@@ -421,8 +432,9 @@ gegl_create_chain_argv (char      **ops,
                       }
                     else
                     if (g_type_is_a (target_type, G_TYPE_DOUBLE) ||
-                        g_type_is_a (target_type, G_TYPE_FLOAT) ||
-                        g_type_is_a (target_type, G_TYPE_INT))
+                        g_type_is_a (target_type, G_TYPE_FLOAT)  ||
+                        g_type_is_a (target_type, G_TYPE_INT)    ||
+                        g_type_is_a (target_type, G_TYPE_UINT))
                       {
                         if (strstr (value, "rel"))
                           {
@@ -440,6 +452,9 @@ gegl_create_chain_argv (char      **ops,
                             if (g_type_is_a (target_type, G_TYPE_INT))
                               gegl_node_set (iter[level], key,
                                              (int)make_rel (value), NULL);
+                            else if (g_type_is_a (target_type, G_TYPE_UINT))
+                              gegl_node_set (iter[level], key,
+                                             (guint)make_rel (value), NULL);
                             else
                               gegl_node_set (iter[level], key,  make_rel (
                                                value), NULL);
@@ -449,10 +464,9 @@ gegl_create_chain_argv (char      **ops,
                             if (g_type_is_a (target_type, G_TYPE_INT))
                               gegl_node_set (iter[level], key,
                                              (int)g_strtod (value, NULL), NULL);
-
-
-
-
+                            else if (g_type_is_a (target_type, G_TYPE_UINT))
+                              gegl_node_set (iter[level], key,
+                                             (guint)g_strtod (value, NULL), NULL);
                             else
                               gegl_node_set (iter[level], key,
                                              g_strtod (value, NULL), NULL);
@@ -490,8 +504,18 @@ gegl_create_chain_argv (char      **ops,
                       {
                         const Babl *format = NULL;
 
-                        if (value[0])
+                        if (value[0] && babl_format_exists (value))
                           format = babl_format (value);
+                        else if (error)
+                          {
+                            char *error_str = g_strdup_printf (
+                                  _("BablFormat \"%s\" does not exist."),
+                                  value);
+                            *error = g_error_new_literal (
+                                        g_quark_from_static_string ( "gegl"),
+                                        0, error_str);
+                            g_free (error_str);
+                          }
 
                         gegl_node_set (iter[level], key, format, NULL);
                       }
@@ -618,7 +642,7 @@ gegl_create_chain_argv (char      **ops,
                   gint started = 0;
                   gint max = 12;
 
-                  g_string_append_printf (str, "No such op '%s'",
+                  g_string_append_printf (str, _("No such op '%s'"),
                                           level_op[level]);
 
                   for (i = 0; i < n_operations; i++)
@@ -874,6 +898,32 @@ gegl_serialize2 (GeglNode *start, GeglNode *end, const char *basepath,
                         printed = TRUE;
                       }
                   }
+                else if (property_type == G_TYPE_UINT)
+                  {
+                    guint defval = g_value_get_uint (default_value);
+                    guint value;
+                    gchar str[64];
+                    gegl_node_get (iter, properties[i]->name, &value, NULL);
+
+                    if (path)
+                    {
+                      g_string_append_printf (s2, " %s={ ", property_name);
+                      if (rel_orig)
+                        gegl_path_foreach (path, each_knot_rel, s2);
+                      else
+                        gegl_path_foreach (path, each_knot, s2);
+                      g_string_append_printf (s2, " } ");
+                    }
+                    else if (value != defval || (!trim_defaults))
+                      {
+                        if (flags & GEGL_SERIALIZE_INDENT)
+                          g_string_append_printf (s2, "  ");
+                        g_snprintf (str, sizeof (str), "%u", value);
+                        g_string_append_printf (s2, " %s=%s%s", property_name,
+                                                str, rel_orig?"rel":"");
+                        printed = TRUE;
+                      }
+                  }
                 else if (property_type == G_TYPE_BOOLEAN)
                   {
                     gboolean value;
