@@ -1,5 +1,6 @@
 #include "config.h"
 #include <gegl-plugin.h>
+void gegl_op_absolute_register_type(GTypeModule *module);
 void gegl_op_alien_map_register_type(GTypeModule *module);
 void gegl_op_bilateral_filter_register_type(GTypeModule *module);
 void gegl_op_box_blur_register_type(GTypeModule *module);
@@ -123,6 +124,7 @@ gegl_module_query (GTypeModule *module)
 G_MODULE_EXPORT gboolean
 gegl_module_register (GTypeModule *module)
 {
+  gegl_op_absolute_register_type(module);
   gegl_op_alien_map_register_type(module);
   gegl_op_bilateral_filter_register_type(module);
   gegl_op_box_blur_register_type(module);
